#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 barbies
version:              2.1.1.0
visibility:           public
id:                   barbies-2.1.1.0-AhKuRVOsfga1KQXVLB5V2C
key:                  barbies-2.1.1.0-AhKuRVOsfga1KQXVLB5V2C
license:              BSD-3-Clause
copyright:            2018 Daniel Gorin
maintainer:           jcpetruzza@gmail.com
author:               Daniel Gorin
homepage:             https://github.com/jcpetruzza/barbies#readme
synopsis:             Classes for working with types that can change clothes.
description:
    Types that are parametric on a functor are like Barbies that have an outfit for each role. This package provides the basic abstractions to work with them comfortably.

category:             Data Structures
abi:                  c1a38d55c1bbb45cbb239bb7a4e93263
exposed:              True
exposed-modules:
    Barbies Barbies.Bare Barbies.Bi Barbies.Constraints
    Barbies.Internal Data.Functor.Barbie Data.Functor.Transformer

hidden-modules:
    Barbies.Generics.Applicative Barbies.Generics.Bare
    Barbies.Generics.Constraints Barbies.Generics.Distributive
    Barbies.Generics.Functor Barbies.Generics.Traversable
    Barbies.Internal.ApplicativeB Barbies.Internal.ApplicativeT
    Barbies.Internal.BareB Barbies.Internal.ConstraintsB
    Barbies.Internal.ConstraintsT Barbies.Internal.Containers
    Barbies.Internal.Dicts Barbies.Internal.DistributiveB
    Barbies.Internal.DistributiveT Barbies.Internal.FunctorB
    Barbies.Internal.FunctorT Barbies.Internal.MonadT
    Barbies.Internal.TraversableB Barbies.Internal.TraversableT
    Barbies.Internal.Trivial Barbies.Internal.Wear
    Barbies.Internal.Wrappers Barbies.Internal.Writer
    Data.Generics.GenericN

import-dirs:          /usr/lib/ghc-9.6.6/site-local/barbies-2.1.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/barbies-2.1.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/barbies-2.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-barbies
hs-libraries:         HSbarbies-2.1.1.0-AhKuRVOsfga1KQXVLB5V2C
depends:
    base-4.18.2.1 distributive-0.6.2.1-79lQt55yOn72OMH7qyBFpo
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-barbies/html/barbies.haddock
haddock-html:         /usr/share/doc/haskell-barbies/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

